appgatewayspb

package
v1.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: Apache-2.0 Imports: 12 Imported by: 2

Documentation

Index

Constants

const (
	AppGatewaysService_ListAppGateways_FullMethodName  = "/google.cloud.beyondcorp.appgateways.v1.AppGatewaysService/ListAppGateways"
	AppGatewaysService_GetAppGateway_FullMethodName    = "/google.cloud.beyondcorp.appgateways.v1.AppGatewaysService/GetAppGateway"
	AppGatewaysService_CreateAppGateway_FullMethodName = "/google.cloud.beyondcorp.appgateways.v1.AppGatewaysService/CreateAppGateway"
	AppGatewaysService_DeleteAppGateway_FullMethodName = "/google.cloud.beyondcorp.appgateways.v1.AppGatewaysService/DeleteAppGateway"
)

Variables

var (
	AppGateway_Type_name = map[int32]string{
		0: "TYPE_UNSPECIFIED",
		1: "TCP_PROXY",
	}
	AppGateway_Type_value = map[string]int32{
		"TYPE_UNSPECIFIED": 0,
		"TCP_PROXY":        1,
	}
)

Enum value maps for AppGateway_Type.

var (
	AppGateway_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "CREATED",
		3: "UPDATING",
		4: "DELETING",
		5: "DOWN",
	}
	AppGateway_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"CREATED":           2,
		"UPDATING":          3,
		"DELETING":          4,
		"DOWN":              5,
	}
)

Enum value maps for AppGateway_State.

var (
	AppGateway_HostType_name = map[int32]string{
		0: "HOST_TYPE_UNSPECIFIED",
		1: "GCP_REGIONAL_MIG",
	}
	AppGateway_HostType_value = map[string]int32{
		"HOST_TYPE_UNSPECIFIED": 0,
		"GCP_REGIONAL_MIG":      1,
	}
)

Enum value maps for AppGateway_HostType.

var AppGatewaysService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.beyondcorp.appgateways.v1.AppGatewaysService",
	HandlerType: (*AppGatewaysServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ListAppGateways",
			Handler:    _AppGatewaysService_ListAppGateways_Handler,
		},
		{
			MethodName: "GetAppGateway",
			Handler:    _AppGatewaysService_GetAppGateway_Handler,
		},
		{
			MethodName: "CreateAppGateway",
			Handler:    _AppGatewaysService_CreateAppGateway_Handler,
		},
		{
			MethodName: "DeleteAppGateway",
			Handler:    _AppGatewaysService_DeleteAppGateway_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/beyondcorp/appgateways/v1/app_gateways_service.proto",
}

AppGatewaysService_ServiceDesc is the grpc.ServiceDesc for AppGatewaysService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_google_cloud_beyondcorp_appgateways_v1_app_gateways_service_proto protoreflect.FileDescriptor

Functions

func RegisterAppGatewaysServiceServer

func RegisterAppGatewaysServiceServer(s grpc.ServiceRegistrar, srv AppGatewaysServiceServer)

Types

type AppGateway

type AppGateway struct {

	// Required. Unique resource name of the AppGateway.
	// The name is ignored when creating an AppGateway.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. Timestamp when the resource was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. Timestamp when the resource was last modified.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Optional. Resource labels to represent user provided metadata.
	Labels map[string]string `` /* 139-byte string literal not displayed */
	// Optional. An arbitrary user-provided name for the AppGateway. Cannot exceed
	// 64 characters.
	DisplayName string `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Output only. A unique identifier for the instance generated by the
	// system.
	Uid string `protobuf:"bytes,6,opt,name=uid,proto3" json:"uid,omitempty"`
	// Required. The type of network connectivity used by the AppGateway.
	Type AppGateway_Type `protobuf:"varint,7,opt,name=type,proto3,enum=google.cloud.beyondcorp.appgateways.v1.AppGateway_Type" json:"type,omitempty"`
	// Output only. The current state of the AppGateway.
	State AppGateway_State `protobuf:"varint,8,opt,name=state,proto3,enum=google.cloud.beyondcorp.appgateways.v1.AppGateway_State" json:"state,omitempty"`
	// Output only. Server-defined URI for this resource.
	Uri string `protobuf:"bytes,9,opt,name=uri,proto3" json:"uri,omitempty"`
	// Output only. A list of connections allocated for the Gateway
	AllocatedConnections []*AppGateway_AllocatedConnection `protobuf:"bytes,10,rep,name=allocated_connections,json=allocatedConnections,proto3" json:"allocated_connections,omitempty"`
	// Required. The type of hosting used by the AppGateway.
	HostType AppGateway_HostType `` /* 151-byte string literal not displayed */
	// contains filtered or unexported fields
}

A BeyondCorp AppGateway resource represents a BeyondCorp protected AppGateway to a remote application. It creates all the necessary GCP components needed for creating a BeyondCorp protected AppGateway. Multiple connectors can be authorised for a single AppGateway.

func (*AppGateway) Descriptor deprecated

func (*AppGateway) Descriptor() ([]byte, []int)

Deprecated: Use AppGateway.ProtoReflect.Descriptor instead.

func (*AppGateway) GetAllocatedConnections

func (x *AppGateway) GetAllocatedConnections() []*AppGateway_AllocatedConnection

func (*AppGateway) GetCreateTime

func (x *AppGateway) GetCreateTime() *timestamppb.Timestamp

func (*AppGateway) GetDisplayName

func (x *AppGateway) GetDisplayName() string

func (*AppGateway) GetHostType

func (x *AppGateway) GetHostType() AppGateway_HostType

func (*AppGateway) GetLabels

func (x *AppGateway) GetLabels() map[string]string

func (*AppGateway) GetName

func (x *AppGateway) GetName() string

func (*AppGateway) GetState

func (x *AppGateway) GetState() AppGateway_State

func (*AppGateway) GetType

func (x *AppGateway) GetType() AppGateway_Type

func (*AppGateway) GetUid

func (x *AppGateway) GetUid() string

func (*AppGateway) GetUpdateTime

func (x *AppGateway) GetUpdateTime() *timestamppb.Timestamp

func (*AppGateway) GetUri

func (x *AppGateway) GetUri() string

func (*AppGateway) ProtoMessage

func (*AppGateway) ProtoMessage()

func (*AppGateway) ProtoReflect

func (x *AppGateway) ProtoReflect() protoreflect.Message

func (*AppGateway) Reset

func (x *AppGateway) Reset()

func (*AppGateway) String

func (x *AppGateway) String() string

type AppGatewayOperationMetadata

type AppGatewayOperationMetadata struct {

	// Output only. The time the operation was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time the operation finished running.
	EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// Output only. Server-defined resource path for the target of the operation.
	Target string `protobuf:"bytes,3,opt,name=target,proto3" json:"target,omitempty"`
	// Output only. Name of the verb executed by the operation.
	Verb string `protobuf:"bytes,4,opt,name=verb,proto3" json:"verb,omitempty"`
	// Output only. Human-readable status of the operation, if any.
	StatusMessage string `protobuf:"bytes,5,opt,name=status_message,json=statusMessage,proto3" json:"status_message,omitempty"`
	// Output only. Identifies whether the user has requested cancellation
	// of the operation. Operations that have successfully been cancelled
	// have [Operation.error][] value with a
	// [google.rpc.Status.code][google.rpc.Status.code] of 1, corresponding to
	// `Code.CANCELLED`.
	RequestedCancellation bool `protobuf:"varint,6,opt,name=requested_cancellation,json=requestedCancellation,proto3" json:"requested_cancellation,omitempty"`
	// Output only. API version used to start the operation.
	ApiVersion string `protobuf:"bytes,7,opt,name=api_version,json=apiVersion,proto3" json:"api_version,omitempty"`
	// contains filtered or unexported fields
}

Represents the metadata of the long-running operation.

func (*AppGatewayOperationMetadata) Descriptor deprecated

func (*AppGatewayOperationMetadata) Descriptor() ([]byte, []int)

Deprecated: Use AppGatewayOperationMetadata.ProtoReflect.Descriptor instead.

func (*AppGatewayOperationMetadata) GetApiVersion

func (x *AppGatewayOperationMetadata) GetApiVersion() string

func (*AppGatewayOperationMetadata) GetCreateTime

func (*AppGatewayOperationMetadata) GetEndTime

func (*AppGatewayOperationMetadata) GetRequestedCancellation

func (x *AppGatewayOperationMetadata) GetRequestedCancellation() bool

func (*AppGatewayOperationMetadata) GetStatusMessage

func (x *AppGatewayOperationMetadata) GetStatusMessage() string

func (*AppGatewayOperationMetadata) GetTarget

func (x *AppGatewayOperationMetadata) GetTarget() string

func (*AppGatewayOperationMetadata) GetVerb

func (x *AppGatewayOperationMetadata) GetVerb() string

func (*AppGatewayOperationMetadata) ProtoMessage

func (*AppGatewayOperationMetadata) ProtoMessage()

func (*AppGatewayOperationMetadata) ProtoReflect

func (*AppGatewayOperationMetadata) Reset

func (x *AppGatewayOperationMetadata) Reset()

func (*AppGatewayOperationMetadata) String

func (x *AppGatewayOperationMetadata) String() string

type AppGateway_AllocatedConnection

type AppGateway_AllocatedConnection struct {

	// Required. The PSC uri of an allocated connection
	PscUri string `protobuf:"bytes,1,opt,name=psc_uri,json=pscUri,proto3" json:"psc_uri,omitempty"`
	// Required. The ingress port of an allocated connection
	IngressPort int32 `protobuf:"varint,2,opt,name=ingress_port,json=ingressPort,proto3" json:"ingress_port,omitempty"`
	// contains filtered or unexported fields
}

Allocated connection of the AppGateway.

func (*AppGateway_AllocatedConnection) Descriptor deprecated

func (*AppGateway_AllocatedConnection) Descriptor() ([]byte, []int)

Deprecated: Use AppGateway_AllocatedConnection.ProtoReflect.Descriptor instead.

func (*AppGateway_AllocatedConnection) GetIngressPort

func (x *AppGateway_AllocatedConnection) GetIngressPort() int32

func (*AppGateway_AllocatedConnection) GetPscUri

func (x *AppGateway_AllocatedConnection) GetPscUri() string

func (*AppGateway_AllocatedConnection) ProtoMessage

func (*AppGateway_AllocatedConnection) ProtoMessage()

func (*AppGateway_AllocatedConnection) ProtoReflect

func (*AppGateway_AllocatedConnection) Reset

func (x *AppGateway_AllocatedConnection) Reset()

func (*AppGateway_AllocatedConnection) String

type AppGateway_HostType

type AppGateway_HostType int32

Enum containing list of all possible host types supported by BeyondCorp Connection.

const (
	// Default value. This value is unused.
	AppGateway_HOST_TYPE_UNSPECIFIED AppGateway_HostType = 0
	// AppGateway hosted in a GCP regional managed instance group.
	AppGateway_GCP_REGIONAL_MIG AppGateway_HostType = 1
)

func (AppGateway_HostType) Descriptor

func (AppGateway_HostType) Enum

func (AppGateway_HostType) EnumDescriptor deprecated

func (AppGateway_HostType) EnumDescriptor() ([]byte, []int)

Deprecated: Use AppGateway_HostType.Descriptor instead.

func (AppGateway_HostType) Number

func (AppGateway_HostType) String

func (x AppGateway_HostType) String() string

func (AppGateway_HostType) Type

type AppGateway_State

type AppGateway_State int32

Represents the different states of an AppGateway.

const (
	// Default value. This value is unused.
	AppGateway_STATE_UNSPECIFIED AppGateway_State = 0
	// AppGateway is being created.
	AppGateway_CREATING AppGateway_State = 1
	// AppGateway has been created.
	AppGateway_CREATED AppGateway_State = 2
	// AppGateway's configuration is being updated.
	AppGateway_UPDATING AppGateway_State = 3
	// AppGateway is being deleted.
	AppGateway_DELETING AppGateway_State = 4
	// AppGateway is down and may be restored in the future.
	// This happens when CCFE sends ProjectState = OFF.
	AppGateway_DOWN AppGateway_State = 5
)

func (AppGateway_State) Descriptor

func (AppGateway_State) Enum

func (AppGateway_State) EnumDescriptor deprecated

func (AppGateway_State) EnumDescriptor() ([]byte, []int)

Deprecated: Use AppGateway_State.Descriptor instead.

func (AppGateway_State) Number

func (AppGateway_State) String

func (x AppGateway_State) String() string

func (AppGateway_State) Type

type AppGateway_Type

type AppGateway_Type int32

Enum containing list of all possible network connectivity options supported by BeyondCorp AppGateway.

const (
	// Default value. This value is unused.
	AppGateway_TYPE_UNSPECIFIED AppGateway_Type = 0
	// TCP Proxy based BeyondCorp Connection. API will default to this if unset.
	AppGateway_TCP_PROXY AppGateway_Type = 1
)

func (AppGateway_Type) Descriptor

func (AppGateway_Type) Enum

func (x AppGateway_Type) Enum() *AppGateway_Type

func (AppGateway_Type) EnumDescriptor deprecated

func (AppGateway_Type) EnumDescriptor() ([]byte, []int)

Deprecated: Use AppGateway_Type.Descriptor instead.

func (AppGateway_Type) Number

func (AppGateway_Type) String

func (x AppGateway_Type) String() string

func (AppGateway_Type) Type

type AppGatewaysServiceClient

type AppGatewaysServiceClient interface {
	// Lists AppGateways in a given project and location.
	ListAppGateways(ctx context.Context, in *ListAppGatewaysRequest, opts ...grpc.CallOption) (*ListAppGatewaysResponse, error)
	// Gets details of a single AppGateway.
	GetAppGateway(ctx context.Context, in *GetAppGatewayRequest, opts ...grpc.CallOption) (*AppGateway, error)
	// Creates a new AppGateway in a given project and location.
	CreateAppGateway(ctx context.Context, in *CreateAppGatewayRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
	// Deletes a single AppGateway.
	DeleteAppGateway(ctx context.Context, in *DeleteAppGatewayRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
}

AppGatewaysServiceClient is the client API for AppGatewaysService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AppGatewaysServiceServer

type AppGatewaysServiceServer interface {
	// Lists AppGateways in a given project and location.
	ListAppGateways(context.Context, *ListAppGatewaysRequest) (*ListAppGatewaysResponse, error)
	// Gets details of a single AppGateway.
	GetAppGateway(context.Context, *GetAppGatewayRequest) (*AppGateway, error)
	// Creates a new AppGateway in a given project and location.
	CreateAppGateway(context.Context, *CreateAppGatewayRequest) (*longrunningpb.Operation, error)
	// Deletes a single AppGateway.
	DeleteAppGateway(context.Context, *DeleteAppGatewayRequest) (*longrunningpb.Operation, error)
}

AppGatewaysServiceServer is the server API for AppGatewaysService service. All implementations should embed UnimplementedAppGatewaysServiceServer for forward compatibility

type CreateAppGatewayRequest

type CreateAppGatewayRequest struct {

	// Required. The resource project name of the AppGateway location using the
	// form: `projects/{project_id}/locations/{location_id}`
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. User-settable AppGateway resource ID.
	//   - Must start with a letter.
	//   - Must contain between 4-63 characters from `/[a-z][0-9]-/`.
	//   - Must end with a number or a letter.
	AppGatewayId string `protobuf:"bytes,2,opt,name=app_gateway_id,json=appGatewayId,proto3" json:"app_gateway_id,omitempty"`
	// Required. A BeyondCorp AppGateway resource.
	AppGateway *AppGateway `protobuf:"bytes,3,opt,name=app_gateway,json=appGateway,proto3" json:"app_gateway,omitempty"`
	// Optional. An optional request ID to identify requests. Specify a unique
	// request ID so that if you must retry your request, the server will know to
	// ignore the request if it has already been completed. The server will
	// guarantee that for at least 60 minutes since the first request.
	//
	// For example, consider a situation where you make an initial request and t
	// he request times out. If you make the request again with the same request
	// ID, the server can check if original operation with the same request ID
	// was received, and if so, will ignore the second request. This prevents
	// clients from accidentally creating duplicate commitments.
	//
	// The request ID must be a valid UUID with the exception that zero UUID is
	// not supported (00000000-0000-0000-0000-000000000000).
	RequestId string `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	// Optional. If set, validates request by executing a dry-run which would not
	// alter the resource in any way.
	ValidateOnly bool `protobuf:"varint,5,opt,name=validate_only,json=validateOnly,proto3" json:"validate_only,omitempty"`
	// contains filtered or unexported fields
}

Request message for BeyondCorp.CreateAppGateway.

func (*CreateAppGatewayRequest) Descriptor deprecated

func (*CreateAppGatewayRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateAppGatewayRequest.ProtoReflect.Descriptor instead.

func (*CreateAppGatewayRequest) GetAppGateway

func (x *CreateAppGatewayRequest) GetAppGateway() *AppGateway

func (*CreateAppGatewayRequest) GetAppGatewayId

func (x *CreateAppGatewayRequest) GetAppGatewayId() string

func (*CreateAppGatewayRequest) GetParent

func (x *CreateAppGatewayRequest) GetParent() string

func (*CreateAppGatewayRequest) GetRequestId

func (x *CreateAppGatewayRequest) GetRequestId() string

func (*CreateAppGatewayRequest) GetValidateOnly

func (x *CreateAppGatewayRequest) GetValidateOnly() bool

func (*CreateAppGatewayRequest) ProtoMessage

func (*CreateAppGatewayRequest) ProtoMessage()

func (*CreateAppGatewayRequest) ProtoReflect

func (x *CreateAppGatewayRequest) ProtoReflect() protoreflect.Message

func (*CreateAppGatewayRequest) Reset

func (x *CreateAppGatewayRequest) Reset()

func (*CreateAppGatewayRequest) String

func (x *CreateAppGatewayRequest) String() string

type DeleteAppGatewayRequest

type DeleteAppGatewayRequest struct {

	// Required. BeyondCorp AppGateway name using the form:
	// `projects/{project_id}/locations/{location_id}/appGateways/{app_gateway_id}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Optional. An optional request ID to identify requests. Specify a unique
	// request ID so that if you must retry your request, the server will know to
	// ignore the request if it has already been completed. The server will
	// guarantee that for at least 60 minutes after the first request.
	//
	// For example, consider a situation where you make an initial request and t
	// he request times out. If you make the request again with the same request
	// ID, the server can check if original operation with the same request ID
	// was received, and if so, will ignore the second request. This prevents
	// clients from accidentally creating duplicate commitments.
	//
	// The request ID must be a valid UUID with the exception that zero UUID is
	// not supported (00000000-0000-0000-0000-000000000000).
	RequestId string `protobuf:"bytes,2,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	// Optional. If set, validates request by executing a dry-run which would not
	// alter the resource in any way.
	ValidateOnly bool `protobuf:"varint,3,opt,name=validate_only,json=validateOnly,proto3" json:"validate_only,omitempty"`
	// contains filtered or unexported fields
}

Request message for BeyondCorp.DeleteAppGateway.

func (*DeleteAppGatewayRequest) Descriptor deprecated

func (*DeleteAppGatewayRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteAppGatewayRequest.ProtoReflect.Descriptor instead.

func (*DeleteAppGatewayRequest) GetName

func (x *DeleteAppGatewayRequest) GetName() string

func (*DeleteAppGatewayRequest) GetRequestId

func (x *DeleteAppGatewayRequest) GetRequestId() string

func (*DeleteAppGatewayRequest) GetValidateOnly

func (x *DeleteAppGatewayRequest) GetValidateOnly() bool

func (*DeleteAppGatewayRequest) ProtoMessage

func (*DeleteAppGatewayRequest) ProtoMessage()

func (*DeleteAppGatewayRequest) ProtoReflect

func (x *DeleteAppGatewayRequest) ProtoReflect() protoreflect.Message

func (*DeleteAppGatewayRequest) Reset

func (x *DeleteAppGatewayRequest) Reset()

func (*DeleteAppGatewayRequest) String

func (x *DeleteAppGatewayRequest) String() string

type GetAppGatewayRequest

type GetAppGatewayRequest struct {

	// Required. BeyondCorp AppGateway name using the form:
	// `projects/{project_id}/locations/{location_id}/appGateways/{app_gateway_id}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

Request message for BeyondCorp.GetAppGateway.

func (*GetAppGatewayRequest) Descriptor deprecated

func (*GetAppGatewayRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetAppGatewayRequest.ProtoReflect.Descriptor instead.

func (*GetAppGatewayRequest) GetName

func (x *GetAppGatewayRequest) GetName() string

func (*GetAppGatewayRequest) ProtoMessage

func (*GetAppGatewayRequest) ProtoMessage()

func (*GetAppGatewayRequest) ProtoReflect

func (x *GetAppGatewayRequest) ProtoReflect() protoreflect.Message

func (*GetAppGatewayRequest) Reset

func (x *GetAppGatewayRequest) Reset()

func (*GetAppGatewayRequest) String

func (x *GetAppGatewayRequest) String() string

type ListAppGatewaysRequest

type ListAppGatewaysRequest struct {

	// Required. The resource name of the AppGateway location using the form:
	// `projects/{project_id}/locations/{location_id}`
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. The maximum number of items to return.
	// If not specified, a default value of 50 will be used by the service.
	// Regardless of the page_size value, the response may include a partial list
	// and a caller should only rely on response's
	// [next_page_token][BeyondCorp.ListAppGatewaysResponse.next_page_token] to
	// determine if there are more instances left to be queried.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. The next_page_token value returned from a previous
	// ListAppGatewaysRequest, if any.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// Optional. A filter specifying constraints of a list operation.
	Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	// Optional. Specifies the ordering of results. See
	// [Sorting
	// order](https://cloud.google.com/apis/design/design_patterns#sorting_order)
	// for more information.
	OrderBy string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
	// contains filtered or unexported fields
}

Request message for BeyondCorp.ListAppGateways.

func (*ListAppGatewaysRequest) Descriptor deprecated

func (*ListAppGatewaysRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListAppGatewaysRequest.ProtoReflect.Descriptor instead.

func (*ListAppGatewaysRequest) GetFilter

func (x *ListAppGatewaysRequest) GetFilter() string

func (*ListAppGatewaysRequest) GetOrderBy

func (x *ListAppGatewaysRequest) GetOrderBy() string

func (*ListAppGatewaysRequest) GetPageSize

func (x *ListAppGatewaysRequest) GetPageSize() int32

func (*ListAppGatewaysRequest) GetPageToken

func (x *ListAppGatewaysRequest) GetPageToken() string

func (*ListAppGatewaysRequest) GetParent

func (x *ListAppGatewaysRequest) GetParent() string

func (*ListAppGatewaysRequest) ProtoMessage

func (*ListAppGatewaysRequest) ProtoMessage()

func (*ListAppGatewaysRequest) ProtoReflect

func (x *ListAppGatewaysRequest) ProtoReflect() protoreflect.Message

func (*ListAppGatewaysRequest) Reset

func (x *ListAppGatewaysRequest) Reset()

func (*ListAppGatewaysRequest) String

func (x *ListAppGatewaysRequest) String() string

type ListAppGatewaysResponse

type ListAppGatewaysResponse struct {

	// A list of BeyondCorp AppGateways in the project.
	AppGateways []*AppGateway `protobuf:"bytes,1,rep,name=app_gateways,json=appGateways,proto3" json:"app_gateways,omitempty"`
	// A token to retrieve the next page of results, or empty if there are no more
	// results in the list.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// A list of locations that could not be reached.
	Unreachable []string `protobuf:"bytes,3,rep,name=unreachable,proto3" json:"unreachable,omitempty"`
	// contains filtered or unexported fields
}

Response message for BeyondCorp.ListAppGateways.

func (*ListAppGatewaysResponse) Descriptor deprecated

func (*ListAppGatewaysResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListAppGatewaysResponse.ProtoReflect.Descriptor instead.

func (*ListAppGatewaysResponse) GetAppGateways

func (x *ListAppGatewaysResponse) GetAppGateways() []*AppGateway

func (*ListAppGatewaysResponse) GetNextPageToken

func (x *ListAppGatewaysResponse) GetNextPageToken() string

func (*ListAppGatewaysResponse) GetUnreachable

func (x *ListAppGatewaysResponse) GetUnreachable() []string

func (*ListAppGatewaysResponse) ProtoMessage

func (*ListAppGatewaysResponse) ProtoMessage()

func (*ListAppGatewaysResponse) ProtoReflect

func (x *ListAppGatewaysResponse) ProtoReflect() protoreflect.Message

func (*ListAppGatewaysResponse) Reset

func (x *ListAppGatewaysResponse) Reset()

func (*ListAppGatewaysResponse) String

func (x *ListAppGatewaysResponse) String() string

type UnimplementedAppGatewaysServiceServer

type UnimplementedAppGatewaysServiceServer struct {
}

UnimplementedAppGatewaysServiceServer should be embedded to have forward compatible implementations.

func (UnimplementedAppGatewaysServiceServer) CreateAppGateway

func (UnimplementedAppGatewaysServiceServer) DeleteAppGateway

func (UnimplementedAppGatewaysServiceServer) GetAppGateway

func (UnimplementedAppGatewaysServiceServer) ListAppGateways

type UnsafeAppGatewaysServiceServer added in v1.2.0

type UnsafeAppGatewaysServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAppGatewaysServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AppGatewaysServiceServer will result in compilation errors.

Jump to