clientgatewayspb

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 13, 2025 License: Apache-2.0 Imports: 11 Imported by: 2

Documentation

Index

Constants

const (
	ClientGatewaysService_ListClientGateways_FullMethodName  = "/google.cloud.beyondcorp.clientgateways.v1.ClientGatewaysService/ListClientGateways"
	ClientGatewaysService_GetClientGateway_FullMethodName    = "/google.cloud.beyondcorp.clientgateways.v1.ClientGatewaysService/GetClientGateway"
	ClientGatewaysService_CreateClientGateway_FullMethodName = "/google.cloud.beyondcorp.clientgateways.v1.ClientGatewaysService/CreateClientGateway"
	ClientGatewaysService_DeleteClientGateway_FullMethodName = "/google.cloud.beyondcorp.clientgateways.v1.ClientGatewaysService/DeleteClientGateway"
)

Variables

var (
	ClientGateway_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "CREATING",
		2: "UPDATING",
		3: "DELETING",
		4: "RUNNING",
		5: "DOWN",
		6: "ERROR",
	}
	ClientGateway_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"CREATING":          1,
		"UPDATING":          2,
		"DELETING":          3,
		"RUNNING":           4,
		"DOWN":              5,
		"ERROR":             6,
	}
)

Enum value maps for ClientGateway_State.

var ClientGatewaysService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.beyondcorp.clientgateways.v1.ClientGatewaysService",
	HandlerType: (*ClientGatewaysServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ListClientGateways",
			Handler:    _ClientGatewaysService_ListClientGateways_Handler,
		},
		{
			MethodName: "GetClientGateway",
			Handler:    _ClientGatewaysService_GetClientGateway_Handler,
		},
		{
			MethodName: "CreateClientGateway",
			Handler:    _ClientGatewaysService_CreateClientGateway_Handler,
		},
		{
			MethodName: "DeleteClientGateway",
			Handler:    _ClientGatewaysService_DeleteClientGateway_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/beyondcorp/clientgateways/v1/client_gateways_service.proto",
}

ClientGatewaysService_ServiceDesc is the grpc.ServiceDesc for ClientGatewaysService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_google_cloud_beyondcorp_clientgateways_v1_client_gateways_service_proto protoreflect.FileDescriptor

Functions

func RegisterClientGatewaysServiceServer

func RegisterClientGatewaysServiceServer(s grpc.ServiceRegistrar, srv ClientGatewaysServiceServer)

Types

type ClientGateway

type ClientGateway struct {

	// Required. name of resource. The name is ignored during creation.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. [Output only] Create time stamp.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. [Output only] Update time stamp.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// Output only. The operational state of the gateway.
	State ClientGateway_State `` /* 131-byte string literal not displayed */
	// Output only. A unique identifier for the instance generated by the system.
	Id string `protobuf:"bytes,5,opt,name=id,proto3" json:"id,omitempty"`
	// Output only. The client connector service name that the client gateway is
	// associated to. Client Connector Services, named as follows:
	//
	//	`projects/{project_id}/locations/{location_id}/client_connector_services/{client_connector_service_id}`.
	ClientConnectorService string `` /* 129-byte string literal not displayed */
	// contains filtered or unexported fields
}

Message describing ClientGateway object.

func (*ClientGateway) Descriptor deprecated

func (*ClientGateway) Descriptor() ([]byte, []int)

Deprecated: Use ClientGateway.ProtoReflect.Descriptor instead.

func (*ClientGateway) GetClientConnectorService

func (x *ClientGateway) GetClientConnectorService() string

func (*ClientGateway) GetCreateTime

func (x *ClientGateway) GetCreateTime() *timestamppb.Timestamp

func (*ClientGateway) GetId

func (x *ClientGateway) GetId() string

func (*ClientGateway) GetName

func (x *ClientGateway) GetName() string

func (*ClientGateway) GetState

func (x *ClientGateway) GetState() ClientGateway_State

func (*ClientGateway) GetUpdateTime

func (x *ClientGateway) GetUpdateTime() *timestamppb.Timestamp

func (*ClientGateway) ProtoMessage

func (*ClientGateway) ProtoMessage()

func (*ClientGateway) ProtoReflect

func (x *ClientGateway) ProtoReflect() protoreflect.Message

func (*ClientGateway) Reset

func (x *ClientGateway) Reset()

func (*ClientGateway) String

func (x *ClientGateway) String() string

type ClientGatewayOperationMetadata

type ClientGatewayOperationMetadata struct {

	// Output only. The time the operation was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time the operation finished running.
	EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// Output only. Server-defined resource path for the target of the operation.
	Target string `protobuf:"bytes,3,opt,name=target,proto3" json:"target,omitempty"`
	// Output only. Name of the verb executed by the operation.
	Verb string `protobuf:"bytes,4,opt,name=verb,proto3" json:"verb,omitempty"`
	// Output only. Human-readable status of the operation, if any.
	StatusMessage string `protobuf:"bytes,5,opt,name=status_message,json=statusMessage,proto3" json:"status_message,omitempty"`
	// Output only. Identifies whether the user has requested cancellation
	// of the operation. Operations that have been cancelled successfully
	// have [Operation.error][] value with a
	// [google.rpc.Status.code][google.rpc.Status.code] of 1, corresponding to
	// `Code.CANCELLED`.
	RequestedCancellation bool `protobuf:"varint,6,opt,name=requested_cancellation,json=requestedCancellation,proto3" json:"requested_cancellation,omitempty"`
	// Output only. API version used to start the operation.
	ApiVersion string `protobuf:"bytes,7,opt,name=api_version,json=apiVersion,proto3" json:"api_version,omitempty"`
	// contains filtered or unexported fields
}

Represents the metadata of the long-running operation.

func (*ClientGatewayOperationMetadata) Descriptor deprecated

func (*ClientGatewayOperationMetadata) Descriptor() ([]byte, []int)

Deprecated: Use ClientGatewayOperationMetadata.ProtoReflect.Descriptor instead.

func (*ClientGatewayOperationMetadata) GetApiVersion

func (x *ClientGatewayOperationMetadata) GetApiVersion() string

func (*ClientGatewayOperationMetadata) GetCreateTime

func (*ClientGatewayOperationMetadata) GetEndTime

func (*ClientGatewayOperationMetadata) GetRequestedCancellation

func (x *ClientGatewayOperationMetadata) GetRequestedCancellation() bool

func (*ClientGatewayOperationMetadata) GetStatusMessage

func (x *ClientGatewayOperationMetadata) GetStatusMessage() string

func (*ClientGatewayOperationMetadata) GetTarget

func (x *ClientGatewayOperationMetadata) GetTarget() string

func (*ClientGatewayOperationMetadata) GetVerb

func (*ClientGatewayOperationMetadata) ProtoMessage

func (*ClientGatewayOperationMetadata) ProtoMessage()

func (*ClientGatewayOperationMetadata) ProtoReflect

func (*ClientGatewayOperationMetadata) Reset

func (x *ClientGatewayOperationMetadata) Reset()

func (*ClientGatewayOperationMetadata) String

type ClientGateway_State

type ClientGateway_State int32

Represents the different states of a gateway.

const (
	// Default value. This value is unused.
	ClientGateway_STATE_UNSPECIFIED ClientGateway_State = 0
	// Gateway is being created.
	ClientGateway_CREATING ClientGateway_State = 1
	// Gateway is being updated.
	ClientGateway_UPDATING ClientGateway_State = 2
	// Gateway is being deleted.
	ClientGateway_DELETING ClientGateway_State = 3
	// Gateway is running.
	ClientGateway_RUNNING ClientGateway_State = 4
	// Gateway is down and may be restored in the future.
	// This happens when CCFE sends ProjectState = OFF.
	ClientGateway_DOWN ClientGateway_State = 5
	// ClientGateway encountered an error and is in indeterministic state.
	ClientGateway_ERROR ClientGateway_State = 6
)

func (ClientGateway_State) Descriptor

func (ClientGateway_State) Enum

func (ClientGateway_State) EnumDescriptor deprecated

func (ClientGateway_State) EnumDescriptor() ([]byte, []int)

Deprecated: Use ClientGateway_State.Descriptor instead.

func (ClientGateway_State) Number

func (ClientGateway_State) String

func (x ClientGateway_State) String() string

func (ClientGateway_State) Type

type ClientGatewaysServiceClient

type ClientGatewaysServiceClient interface {
	// Lists ClientGateways in a given project and location.
	ListClientGateways(ctx context.Context, in *ListClientGatewaysRequest, opts ...grpc.CallOption) (*ListClientGatewaysResponse, error)
	// Gets details of a single ClientGateway.
	GetClientGateway(ctx context.Context, in *GetClientGatewayRequest, opts ...grpc.CallOption) (*ClientGateway, error)
	// Creates a new ClientGateway in a given project and location.
	CreateClientGateway(ctx context.Context, in *CreateClientGatewayRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
	// Deletes a single ClientGateway.
	DeleteClientGateway(ctx context.Context, in *DeleteClientGatewayRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
}

ClientGatewaysServiceClient is the client API for ClientGatewaysService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ClientGatewaysServiceServer

type ClientGatewaysServiceServer interface {
	// Lists ClientGateways in a given project and location.
	ListClientGateways(context.Context, *ListClientGatewaysRequest) (*ListClientGatewaysResponse, error)
	// Gets details of a single ClientGateway.
	GetClientGateway(context.Context, *GetClientGatewayRequest) (*ClientGateway, error)
	// Creates a new ClientGateway in a given project and location.
	CreateClientGateway(context.Context, *CreateClientGatewayRequest) (*longrunningpb.Operation, error)
	// Deletes a single ClientGateway.
	DeleteClientGateway(context.Context, *DeleteClientGatewayRequest) (*longrunningpb.Operation, error)
}

ClientGatewaysServiceServer is the server API for ClientGatewaysService service. All implementations should embed UnimplementedClientGatewaysServiceServer for forward compatibility

type CreateClientGatewayRequest

type CreateClientGatewayRequest struct {

	// Required. Value for parent.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. User-settable client gateway resource ID.
	//   - Must start with a letter.
	//   - Must contain between 4-63 characters from `/[a-z][0-9]-/`.
	//   - Must end with a number or a letter.
	ClientGatewayId string `protobuf:"bytes,2,opt,name=client_gateway_id,json=clientGatewayId,proto3" json:"client_gateway_id,omitempty"`
	// Required. The resource being created.
	ClientGateway *ClientGateway `protobuf:"bytes,3,opt,name=client_gateway,json=clientGateway,proto3" json:"client_gateway,omitempty"`
	// Optional. An optional request ID to identify requests. Specify a unique
	// request ID so that if you must retry your request, the server will know to
	// ignore the request if it has already been completed. The server will
	// guarantee that for at least 60 minutes since the first request.
	//
	// For example, consider a situation where you make an initial request and t
	// he request times out. If you make the request again with the same request
	// ID, the server can check if original operation with the same request ID
	// was received, and if so, will ignore the second request. This prevents
	// clients from accidentally creating duplicate commitments.
	//
	// The request ID must be a valid UUID with the exception that zero UUID is
	// not supported (00000000-0000-0000-0000-000000000000).
	RequestId string `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	// Optional. If set, validates request by executing a dry-run which would not
	// alter the resource in any way.
	ValidateOnly bool `protobuf:"varint,5,opt,name=validate_only,json=validateOnly,proto3" json:"validate_only,omitempty"`
	// contains filtered or unexported fields
}

Message for creating a ClientGateway.

func (*CreateClientGatewayRequest) Descriptor deprecated

func (*CreateClientGatewayRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateClientGatewayRequest.ProtoReflect.Descriptor instead.

func (*CreateClientGatewayRequest) GetClientGateway

func (x *CreateClientGatewayRequest) GetClientGateway() *ClientGateway

func (*CreateClientGatewayRequest) GetClientGatewayId

func (x *CreateClientGatewayRequest) GetClientGatewayId() string

func (*CreateClientGatewayRequest) GetParent

func (x *CreateClientGatewayRequest) GetParent() string

func (*CreateClientGatewayRequest) GetRequestId

func (x *CreateClientGatewayRequest) GetRequestId() string

func (*CreateClientGatewayRequest) GetValidateOnly

func (x *CreateClientGatewayRequest) GetValidateOnly() bool

func (*CreateClientGatewayRequest) ProtoMessage

func (*CreateClientGatewayRequest) ProtoMessage()

func (*CreateClientGatewayRequest) ProtoReflect

func (*CreateClientGatewayRequest) Reset

func (x *CreateClientGatewayRequest) Reset()

func (*CreateClientGatewayRequest) String

func (x *CreateClientGatewayRequest) String() string

type DeleteClientGatewayRequest

type DeleteClientGatewayRequest struct {

	// Required. Name of the resource
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Optional. An optional request ID to identify requests. Specify a unique
	// request ID so that if you must retry your request, the server will know to
	// ignore the request if it has already been completed. The server will
	// guarantee that for at least 60 minutes after the first request.
	//
	// For example, consider a situation where you make an initial request and t
	// he request times out. If you make the request again with the same request
	// ID, the server can check if original operation with the same request ID
	// was received, and if so, will ignore the second request. This prevents
	// clients from accidentally creating duplicate commitments.
	//
	// The request ID must be a valid UUID with the exception that zero UUID is
	// not supported (00000000-0000-0000-0000-000000000000).
	RequestId string `protobuf:"bytes,2,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	// Optional. If set, validates request by executing a dry-run which would not
	// alter the resource in any way.
	ValidateOnly bool `protobuf:"varint,3,opt,name=validate_only,json=validateOnly,proto3" json:"validate_only,omitempty"`
	// contains filtered or unexported fields
}

Message for deleting a ClientGateway

func (*DeleteClientGatewayRequest) Descriptor deprecated

func (*DeleteClientGatewayRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteClientGatewayRequest.ProtoReflect.Descriptor instead.

func (*DeleteClientGatewayRequest) GetName

func (x *DeleteClientGatewayRequest) GetName() string

func (*DeleteClientGatewayRequest) GetRequestId

func (x *DeleteClientGatewayRequest) GetRequestId() string

func (*DeleteClientGatewayRequest) GetValidateOnly

func (x *DeleteClientGatewayRequest) GetValidateOnly() bool

func (*DeleteClientGatewayRequest) ProtoMessage

func (*DeleteClientGatewayRequest) ProtoMessage()

func (*DeleteClientGatewayRequest) ProtoReflect

func (*DeleteClientGatewayRequest) Reset

func (x *DeleteClientGatewayRequest) Reset()

func (*DeleteClientGatewayRequest) String

func (x *DeleteClientGatewayRequest) String() string

type GetClientGatewayRequest

type GetClientGatewayRequest struct {

	// Required. Name of the resource
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

Message for getting a ClientGateway.

func (*GetClientGatewayRequest) Descriptor deprecated

func (*GetClientGatewayRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetClientGatewayRequest.ProtoReflect.Descriptor instead.

func (*GetClientGatewayRequest) GetName

func (x *GetClientGatewayRequest) GetName() string

func (*GetClientGatewayRequest) ProtoMessage

func (*GetClientGatewayRequest) ProtoMessage()

func (*GetClientGatewayRequest) ProtoReflect

func (x *GetClientGatewayRequest) ProtoReflect() protoreflect.Message

func (*GetClientGatewayRequest) Reset

func (x *GetClientGatewayRequest) Reset()

func (*GetClientGatewayRequest) String

func (x *GetClientGatewayRequest) String() string

type ListClientGatewaysRequest

type ListClientGatewaysRequest struct {

	// Required. Parent value for ListClientGatewaysRequest.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. Requested page size. Server may return fewer items than
	// requested. If unspecified, server will pick an appropriate default.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. A token identifying a page of results the server should return.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// Optional. Filtering results.
	Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	// Optional. Hint for how to order the results.
	OrderBy string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
	// contains filtered or unexported fields
}

Message for requesting list of ClientGateways.

func (*ListClientGatewaysRequest) Descriptor deprecated

func (*ListClientGatewaysRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListClientGatewaysRequest.ProtoReflect.Descriptor instead.

func (*ListClientGatewaysRequest) GetFilter

func (x *ListClientGatewaysRequest) GetFilter() string

func (*ListClientGatewaysRequest) GetOrderBy

func (x *ListClientGatewaysRequest) GetOrderBy() string

func (*ListClientGatewaysRequest) GetPageSize

func (x *ListClientGatewaysRequest) GetPageSize() int32

func (*ListClientGatewaysRequest) GetPageToken

func (x *ListClientGatewaysRequest) GetPageToken() string

func (*ListClientGatewaysRequest) GetParent

func (x *ListClientGatewaysRequest) GetParent() string

func (*ListClientGatewaysRequest) ProtoMessage

func (*ListClientGatewaysRequest) ProtoMessage()

func (*ListClientGatewaysRequest) ProtoReflect

func (*ListClientGatewaysRequest) Reset

func (x *ListClientGatewaysRequest) Reset()

func (*ListClientGatewaysRequest) String

func (x *ListClientGatewaysRequest) String() string

type ListClientGatewaysResponse

type ListClientGatewaysResponse struct {

	// The list of ClientGateway.
	ClientGateways []*ClientGateway `protobuf:"bytes,1,rep,name=client_gateways,json=clientGateways,proto3" json:"client_gateways,omitempty"`
	// A token identifying a page of results the server should return.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// Locations that could not be reached.
	Unreachable []string `protobuf:"bytes,3,rep,name=unreachable,proto3" json:"unreachable,omitempty"`
	// contains filtered or unexported fields
}

Message for response to listing ClientGateways.

func (*ListClientGatewaysResponse) Descriptor deprecated

func (*ListClientGatewaysResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListClientGatewaysResponse.ProtoReflect.Descriptor instead.

func (*ListClientGatewaysResponse) GetClientGateways

func (x *ListClientGatewaysResponse) GetClientGateways() []*ClientGateway

func (*ListClientGatewaysResponse) GetNextPageToken

func (x *ListClientGatewaysResponse) GetNextPageToken() string

func (*ListClientGatewaysResponse) GetUnreachable

func (x *ListClientGatewaysResponse) GetUnreachable() []string

func (*ListClientGatewaysResponse) ProtoMessage

func (*ListClientGatewaysResponse) ProtoMessage()

func (*ListClientGatewaysResponse) ProtoReflect

func (*ListClientGatewaysResponse) Reset

func (x *ListClientGatewaysResponse) Reset()

func (*ListClientGatewaysResponse) String

func (x *ListClientGatewaysResponse) String() string

type UnimplementedClientGatewaysServiceServer

type UnimplementedClientGatewaysServiceServer struct {
}

UnimplementedClientGatewaysServiceServer should be embedded to have forward compatible implementations.

func (UnimplementedClientGatewaysServiceServer) CreateClientGateway

func (UnimplementedClientGatewaysServiceServer) DeleteClientGateway

func (UnimplementedClientGatewaysServiceServer) GetClientGateway

func (UnimplementedClientGatewaysServiceServer) ListClientGateways

type UnsafeClientGatewaysServiceServer added in v1.2.0

type UnsafeClientGatewaysServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeClientGatewaysServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ClientGatewaysServiceServer will result in compilation errors.

Jump to